/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <assert.h>
#include <limits.h>
#include <unistd.h>
#include "interface.h"
#include "eprintf.h"

Args *args;

Args *getArgs(int argc, char *argv[]){
  int c;
  char *optString = "hvsr:f:l:s";

  args = (Args *)emalloc(sizeof(Args));
  args->r = NULL;
  args->f = NULL;
  args->l = DEFAULT_L;
  args->s = 0;
  args->h = 0;
  args->v = 0;
  args->e = 0;

  c = getopt(argc, argv, optString);
  while(c != -1){
    switch(c){
    case 'r':                           /* regions to be cut */
      args->r = optarg;
      break;
    case 'f':                           /* file with regions to be cut */
      args->f = optarg;
      break;
    case 'l':                           /* line length */
      args->l = atoi(optarg);
      break;
    case 's':                           /* splice sequences */
      args->s = 1;
      break;
    case '?':                           /* fall-through is intentional */
    case 'h':                           /* print help */
      args->h = 1;
      break;
    case 'v':                           /* print version */
      args->v = 1;
      break;
    default:
      printf("# unknown argument: %c\n",c);
      args->e = 1;
      return args;
    }
    c = getopt(argc, argv, optString);
  }
  if(args->r == NULL && args->f == NULL)
    args->e = 1;
  args->inputFiles = argv + optind;
  args->numInputFiles = argc - optind;
  return args;
}

void printUsage(char *version){
  printf("Purpose: cut regions from molecular sequences\n");
  printf("Usage: cutSeq [options] [files]\n");
  printf("Options:\n");
  printf("\t-r regions, e.g. 256-665,5-100; use -f for large number of regions\n");
  printf("\t[-f file containing regions (one pair of blank-separated start & end positions per line)\n"); 
  printf("\t    default: positions read from -r]\n");
  printf("\t[-s splice regions]\n");
  printf("\t[-l line length; default: %d]\n",DEFAULT_L);
  printf("\t[-h print this help message]\n");
  printf("\t[-v print program information]\n");
}

void printSplash(char *version){
  printf("cutSeq %s\n",version);
  printf("Written by Bernhard Haubold\n");
  printf("Distributed under the GNU General Public License\n");
  printf("Please send bug reports to haubold@evolbio.mpg.de\n");
  exit(0);
}
